#[non_exhaustive]pub struct AttachDiskInput {
pub disk_name: Option<String>,
pub instance_name: Option<String>,
pub disk_path: Option<String>,
pub auto_mounting: Option<bool>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.disk_name: Option<String>The unique Lightsail disk name (my-disk).
instance_name: Option<String>The name of the Lightsail instance where you want to utilize the storage disk.
disk_path: Option<String>The disk path to expose to the instance (/dev/xvdf).
auto_mounting: Option<bool>A Boolean value used to determine the automatic mounting of a storage volume to a virtual computer. The default value is False.
This value only applies to Lightsail for Research resources.
Implementations
Sourceimpl AttachDiskInput
impl AttachDiskInput
Sourcepub fn instance_name(&self) -> Option<&str>
pub fn instance_name(&self) -> Option<&str>
The name of the Lightsail instance where you want to utilize the storage disk.
Sourcepub fn auto_mounting(&self) -> Option<bool>
pub fn auto_mounting(&self) -> Option<bool>
A Boolean value used to determine the automatic mounting of a storage volume to a virtual computer. The default value is False.
This value only applies to Lightsail for Research resources.
Sourceimpl AttachDiskInput
impl AttachDiskInput
Sourcepub fn builder() -> AttachDiskInputBuilder
pub fn builder() -> AttachDiskInputBuilder
Creates a new builder-style object to manufacture AttachDiskInput.