#[non_exhaustive]pub struct CreateBucketInput {
pub bucket_name: Option<String>,
pub bundle_id: Option<String>,
pub tags: Option<Vec<Tag>>,
pub enable_object_versioning: Option<bool>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket_name: Option<String>The name for the bucket.
For more information about bucket names, see Bucket naming rules in Amazon Lightsail in the Amazon Lightsail Developer Guide.
bundle_id: Option<String>The ID of the bundle to use for the bucket.
A bucket bundle specifies the monthly cost, storage space, and data transfer quota for a bucket.
Use the GetBucketBundles action to get a list of bundle IDs that you can specify.
Use the UpdateBucketBundle action to change the bundle after the bucket is created.
The tag keys and optional values to add to the bucket during creation.
Use the TagResource action to tag the bucket after it's created.
enable_object_versioning: Option<bool>A Boolean value that indicates whether to enable versioning of objects in the bucket.
For more information about versioning, see Enabling and suspending object versioning in a bucket in Amazon Lightsail in the Amazon Lightsail Developer Guide.
Implementations
Sourceimpl CreateBucketInput
impl CreateBucketInput
Sourcepub fn bucket_name(&self) -> Option<&str>
pub fn bucket_name(&self) -> Option<&str>
The name for the bucket.
For more information about bucket names, see Bucket naming rules in Amazon Lightsail in the Amazon Lightsail Developer Guide.
Sourcepub fn bundle_id(&self) -> Option<&str>
pub fn bundle_id(&self) -> Option<&str>
The ID of the bundle to use for the bucket.
A bucket bundle specifies the monthly cost, storage space, and data transfer quota for a bucket.
Use the GetBucketBundles action to get a list of bundle IDs that you can specify.
Use the UpdateBucketBundle action to change the bundle after the bucket is created.
The tag keys and optional values to add to the bucket during creation.
Use the TagResource action to tag the bucket after it's created.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourcepub fn enable_object_versioning(&self) -> Option<bool>
pub fn enable_object_versioning(&self) -> Option<bool>
A Boolean value that indicates whether to enable versioning of objects in the bucket.
For more information about versioning, see Enabling and suspending object versioning in a bucket in Amazon Lightsail in the Amazon Lightsail Developer Guide.
Sourceimpl CreateBucketInput
impl CreateBucketInput
Sourcepub fn builder() -> CreateBucketInputBuilder
pub fn builder() -> CreateBucketInputBuilder
Creates a new builder-style object to manufacture CreateBucketInput.