#[non_exhaustive]pub struct UpdateInstanceMetadataOptionsInput {
pub instance_name: Option<String>,
pub http_tokens: Option<HttpTokens>,
pub http_endpoint: Option<HttpEndpoint>,
pub http_put_response_hop_limit: Option<i32>,
pub http_protocol_ipv6: Option<HttpProtocolIpv6>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance_name: Option<String>The name of the instance for which to update metadata parameters.
http_tokens: Option<HttpTokens>The state of token usage for your instance metadata requests. If the parameter is not specified in the request, the default state is optional.
If the state is optional, you can choose whether to retrieve instance metadata with a signed token header on your request. If you retrieve the IAM role credentials without a token, the version 1.0 role credentials are returned. If you retrieve the IAM role credentials by using a valid signed token, the version 2.0 role credentials are returned.
If the state is required, you must send a signed token header with all instance metadata retrieval requests. In this state, retrieving the IAM role credential always returns the version 2.0 credentials. The version 1.0 credentials are not available.
http_endpoint: Option<HttpEndpoint>Enables or disables the HTTP metadata endpoint on your instances. If this parameter is not specified, the existing state is maintained.
If you specify a value of disabled, you cannot access your instance metadata.
http_put_response_hop_limit: Option<i32>The desired HTTP PUT response hop limit for instance metadata requests. A larger number means that the instance metadata requests can travel farther. If no parameter is specified, the existing state is maintained.
http_protocol_ipv6: Option<HttpProtocolIpv6>Enables or disables the IPv6 endpoint for the instance metadata service. This setting applies only when the HTTP metadata endpoint is enabled.
This parameter is available only for instances in the Europe (Stockholm) Amazon Web Services Region (eu-north-1).
Implementations
Sourceimpl UpdateInstanceMetadataOptionsInput
impl UpdateInstanceMetadataOptionsInput
Sourcepub fn instance_name(&self) -> Option<&str>
pub fn instance_name(&self) -> Option<&str>
The name of the instance for which to update metadata parameters.
Sourcepub fn http_tokens(&self) -> Option<&HttpTokens>
pub fn http_tokens(&self) -> Option<&HttpTokens>
The state of token usage for your instance metadata requests. If the parameter is not specified in the request, the default state is optional.
If the state is optional, you can choose whether to retrieve instance metadata with a signed token header on your request. If you retrieve the IAM role credentials without a token, the version 1.0 role credentials are returned. If you retrieve the IAM role credentials by using a valid signed token, the version 2.0 role credentials are returned.
If the state is required, you must send a signed token header with all instance metadata retrieval requests. In this state, retrieving the IAM role credential always returns the version 2.0 credentials. The version 1.0 credentials are not available.
Sourcepub fn http_endpoint(&self) -> Option<&HttpEndpoint>
pub fn http_endpoint(&self) -> Option<&HttpEndpoint>
Enables or disables the HTTP metadata endpoint on your instances. If this parameter is not specified, the existing state is maintained.
If you specify a value of disabled, you cannot access your instance metadata.
Sourcepub fn http_put_response_hop_limit(&self) -> Option<i32>
pub fn http_put_response_hop_limit(&self) -> Option<i32>
The desired HTTP PUT response hop limit for instance metadata requests. A larger number means that the instance metadata requests can travel farther. If no parameter is specified, the existing state is maintained.
Sourcepub fn http_protocol_ipv6(&self) -> Option<&HttpProtocolIpv6>
pub fn http_protocol_ipv6(&self) -> Option<&HttpProtocolIpv6>
Enables or disables the IPv6 endpoint for the instance metadata service. This setting applies only when the HTTP metadata endpoint is enabled.
This parameter is available only for instances in the Europe (Stockholm) Amazon Web Services Region (eu-north-1).
Sourceimpl UpdateInstanceMetadataOptionsInput
impl UpdateInstanceMetadataOptionsInput
Sourcepub fn builder() -> UpdateInstanceMetadataOptionsInputBuilder
pub fn builder() -> UpdateInstanceMetadataOptionsInputBuilder
Creates a new builder-style object to manufacture UpdateInstanceMetadataOptionsInput.