DistributionBundle

Struct DistributionBundle 

#[non_exhaustive]
pub struct DistributionBundle { pub bundle_id: Option<String>, pub name: Option<String>, pub price: Option<f32>, pub transfer_per_month_in_gb: Option<i32>, pub is_active: Option<bool>, }
Describes the specifications of a distribution bundle.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
bundle_id: Option<String>

The ID of the bundle.

name: Option<String>

The name of the distribution bundle.

price: Option<f32>

The monthly price, in US dollars, of the bundle.

transfer_per_month_in_gb: Option<i32>

The monthly network transfer quota of the bundle.

is_active: Option<bool>

Indicates whether the bundle is active, and can be specified for a new or existing distribution.

Implementations

Source

impl DistributionBundle

pub fn bundle_id(&self) -> Option<&str>

The ID of the bundle.

pub fn name(&self) -> Option<&str>

The name of the distribution bundle.

pub fn price(&self) -> Option<f32>

The monthly price, in US dollars, of the bundle.

pub fn transfer_per_month_in_gb(&self) -> Option<i32>

The monthly network transfer quota of the bundle.

pub fn is_active(&self) -> Option<bool>

Indicates whether the bundle is active, and can be specified for a new or existing distribution.

Source

impl DistributionBundle

pub fn builder() -> DistributionBundleBuilder

Creates a new builder-style object to manufacture DistributionBundle.