#[non_exhaustive]pub struct HostKeyAttributes {
pub algorithm: Option<String>,
pub public_key: Option<String>,
pub witnessed_at: Option<DateTime>,
pub fingerprint_sha1: Option<String>,
pub fingerprint_sha256: Option<String>,
pub not_valid_before: Option<DateTime>,
pub not_valid_after: Option<DateTime>,
}Expand description
Describes the public SSH host keys or the RDP certificate.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.algorithm: Option<String>The SSH host key algorithm or the RDP certificate format.
For SSH host keys, the algorithm may be ssh-rsa, ecdsa-sha2-nistp256, ssh-ed25519, etc. For RDP certificates, the algorithm is always x509-cert.
public_key: Option<String>The public SSH host key or the RDP certificate.
witnessed_at: Option<DateTime>The time that the SSH host key or RDP certificate was recorded by Lightsail.
fingerprint_sha1: Option<String>The SHA-1 fingerprint of the returned SSH host key or RDP certificate.
-
Example of an SHA-1 SSH fingerprint:
SHA1:1CHH6FaAaXjtFOsR/t83vf91SR0 -
Example of an SHA-1 RDP fingerprint:
af:34:51:fe:09:f0:e0:da:b8:4e:56:ca:60:c2:10:ff:38:06:db:45
fingerprint_sha256: Option<String>The SHA-256 fingerprint of the returned SSH host key or RDP certificate.
-
Example of an SHA-256 SSH fingerprint:
SHA256:KTsMnRBh1IhD17HpdfsbzeGA4jOijm5tyXsMjKVbB8o -
Example of an SHA-256 RDP fingerprint:
03:9b:36:9f:4b:de:4e:61:70:fc:7c:c9:78:e7:d2:1a:1c:25:a8:0c:91:f6:7c:e4:d6:a0:85:c8:b4:53:99:68
not_valid_before: Option<DateTime>The returned RDP certificate is valid after this point in time.
This value is listed only for RDP certificates.
not_valid_after: Option<DateTime>The returned RDP certificate is not valid after this point in time.
This value is listed only for RDP certificates.
Implementations
Sourceimpl HostKeyAttributes
impl HostKeyAttributes
Sourcepub fn algorithm(&self) -> Option<&str>
pub fn algorithm(&self) -> Option<&str>
The SSH host key algorithm or the RDP certificate format.
For SSH host keys, the algorithm may be ssh-rsa, ecdsa-sha2-nistp256, ssh-ed25519, etc. For RDP certificates, the algorithm is always x509-cert.
Sourcepub fn public_key(&self) -> Option<&str>
pub fn public_key(&self) -> Option<&str>
The public SSH host key or the RDP certificate.
Sourcepub fn witnessed_at(&self) -> Option<&DateTime>
pub fn witnessed_at(&self) -> Option<&DateTime>
The time that the SSH host key or RDP certificate was recorded by Lightsail.
Sourcepub fn fingerprint_sha1(&self) -> Option<&str>
pub fn fingerprint_sha1(&self) -> Option<&str>
The SHA-1 fingerprint of the returned SSH host key or RDP certificate.
-
Example of an SHA-1 SSH fingerprint:
SHA1:1CHH6FaAaXjtFOsR/t83vf91SR0 -
Example of an SHA-1 RDP fingerprint:
af:34:51:fe:09:f0:e0:da:b8:4e:56:ca:60:c2:10:ff:38:06:db:45
Sourcepub fn fingerprint_sha256(&self) -> Option<&str>
pub fn fingerprint_sha256(&self) -> Option<&str>
The SHA-256 fingerprint of the returned SSH host key or RDP certificate.
-
Example of an SHA-256 SSH fingerprint:
SHA256:KTsMnRBh1IhD17HpdfsbzeGA4jOijm5tyXsMjKVbB8o -
Example of an SHA-256 RDP fingerprint:
03:9b:36:9f:4b:de:4e:61:70:fc:7c:c9:78:e7:d2:1a:1c:25:a8:0c:91:f6:7c:e4:d6:a0:85:c8:b4:53:99:68
Sourcepub fn not_valid_before(&self) -> Option<&DateTime>
pub fn not_valid_before(&self) -> Option<&DateTime>
The returned RDP certificate is valid after this point in time.
This value is listed only for RDP certificates.
Sourcepub fn not_valid_after(&self) -> Option<&DateTime>
pub fn not_valid_after(&self) -> Option<&DateTime>
The returned RDP certificate is not valid after this point in time.
This value is listed only for RDP certificates.
Sourceimpl HostKeyAttributes
impl HostKeyAttributes
Sourcepub fn builder() -> HostKeyAttributesBuilder
pub fn builder() -> HostKeyAttributesBuilder
Creates a new builder-style object to manufacture HostKeyAttributes.