#[non_exhaustive]pub struct InstanceSnapshot {Show 16 fields
pub name: Option<String>,
pub arn: Option<String>,
pub support_code: Option<String>,
pub created_at: Option<DateTime>,
pub location: Option<ResourceLocation>,
pub resource_type: Option<ResourceType>,
pub tags: Option<Vec<Tag>>,
pub state: Option<InstanceSnapshotState>,
pub progress: Option<String>,
pub from_attached_disks: Option<Vec<Disk>>,
pub from_instance_name: Option<String>,
pub from_instance_arn: Option<String>,
pub from_blueprint_id: Option<String>,
pub from_bundle_id: Option<String>,
pub is_from_auto_snapshot: Option<bool>,
pub size_in_gb: Option<i32>,
}Expand description
Describes an instance snapshot.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the snapshot.
arn: Option<String>The Amazon Resource Name (ARN) of the snapshot (arn:aws:lightsail:us-east-2:123456789101:InstanceSnapshot/d23b5706-3322-4d83-81e5-12345EXAMPLE).
support_code: Option<String>The support code. Include this code in your email to support when you have questions about an instance or another resource in Lightsail. This code enables our support team to look up your Lightsail information more easily.
created_at: Option<DateTime>The timestamp when the snapshot was created (1479907467.024).
location: Option<ResourceLocation>The region name and Availability Zone where you created the snapshot.
resource_type: Option<ResourceType>The type of resource (usually InstanceSnapshot).
The tag keys and optional values for the resource. For more information about tags in Lightsail, see the Amazon Lightsail Developer Guide.
state: Option<InstanceSnapshotState>The state the snapshot is in.
progress: Option<String>The progress of the snapshot.
This is populated only for disk snapshots, and is null for instance snapshots.
from_attached_disks: Option<Vec<Disk>>An array of disk objects containing information about all block storage disks.
from_instance_name: Option<String>The instance from which the snapshot was created.
from_instance_arn: Option<String>The Amazon Resource Name (ARN) of the instance from which the snapshot was created (arn:aws:lightsail:us-east-2:123456789101:Instance/64b8404c-ccb1-430b-8daf-12345EXAMPLE).
from_blueprint_id: Option<String>The blueprint ID from which you created the snapshot (amazon_linux_2023). A blueprint is a virtual private server (or instance) image used to create instances quickly.
from_bundle_id: Option<String>The bundle ID from which you created the snapshot (micro_x_x).
is_from_auto_snapshot: Option<bool>A Boolean value indicating whether the snapshot was created from an automatic snapshot.
size_in_gb: Option<i32>The size in GB of the SSD.
Implementations
Sourceimpl InstanceSnapshot
impl InstanceSnapshot
Sourcepub fn arn(&self) -> Option<&str>
pub fn arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the snapshot (arn:aws:lightsail:us-east-2:123456789101:InstanceSnapshot/d23b5706-3322-4d83-81e5-12345EXAMPLE).
Sourcepub fn support_code(&self) -> Option<&str>
pub fn support_code(&self) -> Option<&str>
The support code. Include this code in your email to support when you have questions about an instance or another resource in Lightsail. This code enables our support team to look up your Lightsail information more easily.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp when the snapshot was created (1479907467.024).
Sourcepub fn location(&self) -> Option<&ResourceLocation>
pub fn location(&self) -> Option<&ResourceLocation>
The region name and Availability Zone where you created the snapshot.
Sourcepub fn resource_type(&self) -> Option<&ResourceType>
pub fn resource_type(&self) -> Option<&ResourceType>
The type of resource (usually InstanceSnapshot).
The tag keys and optional values for the resource. For more information about tags in Lightsail, see the Amazon Lightsail Developer Guide.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourcepub fn state(&self) -> Option<&InstanceSnapshotState>
pub fn state(&self) -> Option<&InstanceSnapshotState>
The state the snapshot is in.
Sourcepub fn progress(&self) -> Option<&str>
pub fn progress(&self) -> Option<&str>
The progress of the snapshot.
This is populated only for disk snapshots, and is null for instance snapshots.
Sourcepub fn from_attached_disks(&self) -> &[Disk]
pub fn from_attached_disks(&self) -> &[Disk]
An array of disk objects containing information about all block storage disks.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .from_attached_disks.is_none().
Sourcepub fn from_instance_name(&self) -> Option<&str>
pub fn from_instance_name(&self) -> Option<&str>
The instance from which the snapshot was created.
Sourcepub fn from_instance_arn(&self) -> Option<&str>
pub fn from_instance_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the instance from which the snapshot was created (arn:aws:lightsail:us-east-2:123456789101:Instance/64b8404c-ccb1-430b-8daf-12345EXAMPLE).
Sourcepub fn from_blueprint_id(&self) -> Option<&str>
pub fn from_blueprint_id(&self) -> Option<&str>
The blueprint ID from which you created the snapshot (amazon_linux_2023). A blueprint is a virtual private server (or instance) image used to create instances quickly.
Sourcepub fn from_bundle_id(&self) -> Option<&str>
pub fn from_bundle_id(&self) -> Option<&str>
The bundle ID from which you created the snapshot (micro_x_x).
Sourcepub fn is_from_auto_snapshot(&self) -> Option<bool>
pub fn is_from_auto_snapshot(&self) -> Option<bool>
A Boolean value indicating whether the snapshot was created from an automatic snapshot.
Sourcepub fn size_in_gb(&self) -> Option<i32>
pub fn size_in_gb(&self) -> Option<i32>
The size in GB of the SSD.
Sourceimpl InstanceSnapshot
impl InstanceSnapshot
Sourcepub fn builder() -> InstanceSnapshotBuilder
pub fn builder() -> InstanceSnapshotBuilder
Creates a new builder-style object to manufacture InstanceSnapshot.