#[non_exhaustive]pub struct PasswordData {
pub ciphertext: Option<String>,
pub key_pair_name: Option<String>,
}Expand description
The password data for the Windows Server-based instance, including the ciphertext and the key pair name.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ciphertext: Option<String>The encrypted password. Ciphertext will be an empty string if access to your new instance is not ready yet. When you create an instance, it can take up to 15 minutes for the instance to be ready.
If you use the default key pair (LightsailDefaultKeyPair), the decrypted password will be available in the password field.
If you are using a custom key pair, you need to use your own means of decryption.
If you change the Administrator password on the instance, Lightsail will continue to return the original ciphertext value. When accessing the instance using RDP, you need to manually enter the Administrator password after changing it from the default.
key_pair_name: Option<String>The name of the key pair that you used when creating your instance. If no key pair name was specified when creating the instance, Lightsail uses the default key pair (LightsailDefaultKeyPair).
If you are using a custom key pair, you need to use your own means of decrypting your password using the ciphertext. Lightsail creates the ciphertext by encrypting your password with the public key part of this key pair.
Implementations
Sourceimpl PasswordData
impl PasswordData
Sourcepub fn ciphertext(&self) -> Option<&str>
pub fn ciphertext(&self) -> Option<&str>
The encrypted password. Ciphertext will be an empty string if access to your new instance is not ready yet. When you create an instance, it can take up to 15 minutes for the instance to be ready.
If you use the default key pair (LightsailDefaultKeyPair), the decrypted password will be available in the password field.
If you are using a custom key pair, you need to use your own means of decryption.
If you change the Administrator password on the instance, Lightsail will continue to return the original ciphertext value. When accessing the instance using RDP, you need to manually enter the Administrator password after changing it from the default.
Sourcepub fn key_pair_name(&self) -> Option<&str>
pub fn key_pair_name(&self) -> Option<&str>
The name of the key pair that you used when creating your instance. If no key pair name was specified when creating the instance, Lightsail uses the default key pair (LightsailDefaultKeyPair).
If you are using a custom key pair, you need to use your own means of decrypting your password using the ciphertext. Lightsail creates the ciphertext by encrypting your password with the public key part of this key pair.
Sourceimpl PasswordData
impl PasswordData
Sourcepub fn builder() -> PasswordDataBuilder
pub fn builder() -> PasswordDataBuilder
Creates a new builder-style object to manufacture PasswordData.